==> sc_diff_analysis-0.0.11-py3-none-any.whl: sc_diff_analysis/analyzer/diff_analyzer.py <==
#  The MIT License (MIT)
#
#  Copyright (c) 2021. Scott Lau
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.

from . import BranchSummaryGroupByBranchDiffAnalyzer, BranchSummaryGroupByItemTypeDiffAnalyzer


class DiffAnalyzer:
    """
    差异分析类
    """

    def __init__(self):
        pass

    def analysis(self):
        # 机构汇总差异分析
        diff_analyzer = BranchSummaryGroupByBranchDiffAnalyzer(is_first_analyzer=True)
        result = diff_analyzer.analysis()
        if result != 0:
            return result
        # 按差异类型分组进行差异分析
        diff_analyzer = BranchSummaryGroupByItemTypeDiffAnalyzer()
        result = diff_analyzer.analysis()
        if result != 0:
            return result
        return result

==> sc_diff_analysis-0.0.12-py3-none-any.whl: sc_diff_analysis/analyzer/diff_analyzer.py <==
#  The MIT License (MIT)
#
#  Copyright (c) 2021. Scott Lau
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.

from . import BranchSummaryGroupByBranchDiffAnalyzer, BranchSummaryGroupByItemTypeDiffAnalyzer
from sc_diff_analysis.utils import ConfigUtils


class DiffAnalyzer:
    """
    差异分析类
    """

    def __init__(self):
        pass

    def analysis(self):
        config = ConfigUtils.get_config()
        # 机构汇总差异分析
        diff_analyzer = BranchSummaryGroupByBranchDiffAnalyzer(config=config, is_first_analyzer=True)
        result = diff_analyzer.analysis()
        if result != 0:
            return result
        # 按差异类型分组进行差异分析
        diff_analyzer = BranchSummaryGroupByItemTypeDiffAnalyzer(config=config)
        result = diff_analyzer.analysis()
        if result != 0:
            return result
        return result
